Method: Formed::Relation#new
- Defined in:
- lib/formed/relation.rb
#new(attributes = nil, &block) ⇒ Object Also known as: build
Initializes new record from relation while maintaining the current scope.
Expects arguments in the same format as ActiveRecord::Base.new.
users = User.where(name: 'DHH')
user = users.new # => #<User id: nil, name: "DHH", created_at: nil, updated_at: nil>
You can also pass a block to new with the new record as argument:
user = users.new { |user| user.name = 'Oscar' }
user.name # => Oscar
40 41 42 43 44 45 46 47 |
# File 'lib/formed/relation.rb', line 40 def new(attributes = nil, &block) if attributes.is_a?(Array) attributes.collect { |attr| new(attr, &block) } else block = current_scope_restoring_block(&block) scoping { _new(attributes, &block) } end end |